@@ -1,6 +1,5 @@
 import click
 
-from convisoappsec.flow import api
 from convisoappsec.flowcli.context import pass_flow_context
 from convisoappsec.flow.version_searchers import SortedByVersioningStyle
 from convisoappsec.flow.version_control_system_adapter import GitAdapter
@@ -12,13 +11,15 @@ from convisoappsec.flowcli.deploy.create.with_.tag_tracker.context import (
     pass_tag_tracker_context
 )
 
+
 @click.command()
 @project_code_option()
 @click.option(
     '-c',
     '--current-tag',
     required=False,
-    help="This value is used to ignore versions bigger than this value if exists"
+    help="""This value is used to ignore versions
+    bigger than this value if exists"""
 )
 @click.option(
     '-i',
